#!/bin/bash
# packager          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# package           :soundconverter
# homepage          : http://soundconverter.berlios.de/
# dependency        : gstreamer,libglade,pygtk

softname='soundconverter'
softversion='2.0.2'
packageversion='72.1'

arch='i686'
cpu='i686'

prefix=/usr

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.xz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://launchpad.net/$softname/trunk/$softversion/+download/$softname-$softversion.tar.xz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps/
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
              |-----handy-ruler------------------------------------------------------|
soundconverter: soundconverter - Convert sound files to other formats
soundconverter: 
soundconverter: A simple sound converter application for the GNOME environment. 
soundconverter: It reads anything the GStreamer library can read, and writes WAV,
soundconverter: FLAC, MP3, and Ogg Vorbis files.
soundconverter:  
soundconverter: 
soundconverter: 
soundconverter: 
soundconverter: 
soundconverter:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.xz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# log
(

# build
    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

#	patch -p1 < ../0001-Fix-set-syntax-in-gstreamer.py.patch

    ./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--localedir="/usr/share/locale" \
	--disable-static \
	--enable-shared \
	--build=$arch-slackware-linux || exit

make
make install DESTDIR=$dest

# make .desktop
rm $dest/usr/share/applications/$softname.desktop
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Version=1.0
Encoding=UTF-8
Name=Sound Converter
Name[ar]=محول الصوت
Name[cs]=Převaděč zvuků
Name[de]=Sound Converter
Name[en_GB]=Sound Converter
Name[es]=Conversor de Sonido
Name[fr]=Convertisseur Audio SoundConverter
Name[he]=ממיר סאונד
Name[it]=Sound Converter - Convertitore Audio
Name[ms]=Penukar Audio
Name[nl]=Sound Converter
Name[pl]=Konwerter Dźwięku
Name[pt_BR]=Conversor de Som
Name[ru]=Аудиоконвертор
Name[sk]=Zvukový konvertor
Name[sr]=Prekoder zvuka
Name[sr@Latn]=Prekoder zvuka
Name[sv_SE]=Ljudkonverterare
Name[zh_CN]=声音转换程序
GenericName=Audio Format Converter
GenericName[ar]=محول أشكال الملفات الصوتية
GenericName[cs]=Převaděč zvukových formátů
GenericName[de]=Audioformat Konverter
GenericName[en_GB]=Audio Format Converter
GenericName[es]=Conversor de formatos de audio
GenericName[fr]=Convertion entre formats audios
GenericName[he]=ממיר פורמטים של אודיו
GenericName[it]=Convertitore formati audio
GenericName[ms]=Penukar Format Audio
GenericName[ru]=Аудиоконвертор
GenericName[sk]=Konvertor zvukového formátu
GenericName[sr@Latn]=Prekodiranje zvučnih formata
GenericName[sv_SE]=Ljudformatskonverterare
GenericName[zh_CN]=音频格式转换程序
Comment=Convert audio files into other formats
Comment[ar]=تحويل الملفات الصوتيه الى صيغ اخرى
Comment[ca]=Convertir arxius d'audio a d'altres formats
Comment[cs]=Převeďte zvukové soubory do jiných formátů
Comment[de]=Konvertierung von Audiodateien in andere Formate
Comment[en_GB]=Convert audio files into other formats
Comment[es]=Convertir archivos de audio a otros formatos
Comment[fr]=Convertit les fichiers audios vers d'autres formats
Comment[he]=ממיר קבצי אודיו לפורמטים שונים
Comment[it]=Converte un file audio in un'altro formato
Comment[ms]=Tukar file audio ke format yang lain
Comment[nl]=Geluidsbestanden omzetten naar andere formats
Comment[pl]=Konwertuj pliki audion do innych formatów
Comment[pt_BR]=Converter arquivos de audio em outros formatos
Comment[ru]=Позволяет конвертировать аудиофайлы в разные форматы
Comment[sk]=Konvertuj zvukové súbory do iného formátu
Comment[sr]=Prevedi jedan zvučni format u druge
Comment[sr@Latn]=Prevedi jedan zvučni format u druge
Comment[sv_SE]=Konvertera ljudfiler till andra format
Comment[zh_CN]=把音频文件转换为其它格式
Icon=soundconverter
MimeType=application/x-ogg;application/ogg;audio/x-mp3;audio/x-scpls;audio/x-mp3;audio/x-mpeg;audio/mpeg;audio/x-mpegurl;application/x-flac;audio/x-wav;
Exec=soundconverter %U
Terminal=false
Type=Application
StartupNotify=true
Categories=GNOME;GTK;AudioVideo;
EOF
 
# add 'default' files
    cp -a \
      AUTHORS COPYING ChangeLog INSTALL NEWS README TODO\
      $dest/usr/doc/$softname-$softversion

#  strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 640 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -type d -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
echo -e "libgnome,libgnomeui,gconf,glib2,gnome-vfs,gnome-python,gstreamer,gst-python,\
gst-plugins-base,gst-plugins-good-extra,gst-plugins-bad-extra,gst-plugins-ugly-extra,gtk+2,libglade,pygtk,python,xorg-server,libxcb" > $package.dep

# erase source
rm -rf $src
rm -rf $dest

# generate source file
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/soundconverter/source/build-soundconverter.sh > $package.src
echo $source >> $package.src

# log
) 2>&1 | tee "$softname-$softversion-build.log"
